@@ -1,6 +1,6 @@
-#!/bin/bash -eux
+#!/usr/bin/env bash
 
-set -o pipefail
+set -o pipefail -eux
 
 declare -a args
 IFS='/:' read -ra args <<< "$1"
@@ -16,9 +16,10 @@ provider="${P:-default}"
 # python versions to test in order
 # python 2.7 runs full tests while other versions run minimal tests
 python_versions=(
-    2.6
     3.5
     3.6
+    3.7
+    3.8
     2.7
 )
 
@@ -26,8 +27,8 @@ python_versions=(
 single_version=2012-R2
 
 # shellcheck disable=SC2086
-ansible-test windows-integration "${target}" --explain ${CHANGED:+"$CHANGED"} ${UNSTABLE:+"$UNSTABLE"} 2>&1 \
-    | { grep ' windows-integration: .* (targeted)$' || true; } > /tmp/windows.txt
+ansible-test windows-integration --explain ${CHANGED:+"$CHANGED"} ${UNSTABLE:+"$UNSTABLE"} > /tmp/explain.txt 2>&1 || { cat /tmp/explain.txt && false; }
+{ grep ' windows-integration: .* (targeted)$' /tmp/explain.txt || true; } > /tmp/windows.txt
 
 if [ -s /tmp/windows.txt ] || [ "${CHANGED:+$CHANGED}" == "" ]; then
     echo "Detected changes requiring integration tests specific to Windows:"
@@ -54,6 +55,7 @@ fi
 
 for version in "${python_versions[@]}"; do
     changed_all_target="all"
+    changed_all_mode="default"
 
     if [ "${version}" == "2.7" ]; then
         # smoketest tests for python 2.7
@@ -61,12 +63,13 @@ for version in "${python_versions[@]}"; do
             # with change detection enabled run tests for anything changed
             # use the smoketest tests for any change that triggers all tests
             ci="${target}"
+            changed_all_target="shippable/windows/smoketest/"
             if [ "${target}" == "shippable/windows/group1/" ]; then
                 # only run smoketest tests for group1
-                changed_all_target="shippable/windows/smoketest/"
+                changed_all_mode="include"
             else
                 # smoketest tests already covered by group1
-                changed_all_target="none"
+                changed_all_mode="exclude"
             fi
         else
             # without change detection enabled run entire test group
@@ -88,7 +91,7 @@ for version in "${python_versions[@]}"; do
 
     # shellcheck disable=SC2086
     ansible-test windows-integration --color -v --retry-on-error "${ci}" ${COVERAGE:+"$COVERAGE"} ${CHANGED:+"$CHANGED"} ${UNSTABLE:+"$UNSTABLE"} \
-        "${platforms[@]}" --changed-all-target "${changed_all_target}" \
+        "${platforms[@]}" --changed-all-target "${changed_all_target}" --changed-all-mode "${changed_all_mode}" \
         --docker default --python "${version}" \
         --remote-terminate "${terminate}" --remote-stage "${stage}" --remote-provider "${provider}"
 done
